==> 2.2.3.tar.gz: lib/XfXWidgets/XfxItemForList.dart <==
part of xwidgetbase;

class XfxItemForList extends StatefulWidget {
  XfxItemForList({Key? key, this.title = "", this.descr, this.note, this.editable, this.colorBorderReadOnly}) : super(key: key);
  final String title;
  final String? descr;
  final String? note;
  final bool? editable;
  final Color? colorBorderReadOnly;
  @override
  _XfxItemForListState createState() => _XfxItemForListState();
}

class _XfxItemForListState extends State<XfxItemForList> {
  InputBorder? borderStyle() {
    return UnderlineInputBorder(borderRadius: BorderRadius.all(Radius.circular(4.0)), borderSide: BorderSide(width: 1, color: Colors.white));
  }

  @override
  Widget build(BuildContext context) {
    return Row(
      children: [
        Expanded(
            child: Container(
                decoration: BoxDecoration(
                  borderRadius: BorderRadius.all(Radius.circular(10)),
                  color: Colors.grey[850],
                ),
                margin: EdgeInsets.only(
                  bottom: 5,
                ),
                padding: EdgeInsets.only(bottom: 5),
                alignment: Alignment.centerLeft,
                child: Row(children: [
                  Expanded(
                      child: widget.editable == true
                          ? XTextFormField(
                              height: 40,
                              textColor: XColors.xcolor_ForegroundLight,
                              initialValue: widget.title,
                              border: borderStyle(),
                              disabledBorder: borderStyle(),
                              enabledBorder: borderStyle(),
                            )
                          : Container(height: 40, decoration: BoxDecoration(), alignment: Alignment.center, child: Text(widget.title))),
                  Expanded(
                      child: widget.editable == true
                          ? XTextFormField(height: 40, initialValue: widget.descr, border: borderStyle(), disabledBorder: borderStyle(), enabledBorder: borderStyle(), hintStyle: TextStyle(color: XColors.xcolor_ForegroundLight))
                          : Container(height: 40, decoration: BoxDecoration(), alignment: Alignment.center, child: Text(widget.descr ?? ""))),
                  Expanded(
                      child: widget.editable == true
                          ? XTextFormField(height: 40, initialValue: widget.note, border: borderStyle(), disabledBorder: borderStyle(), enabledBorder: borderStyle())
                          : Container(height: 40, decoration: BoxDecoration(), alignment: Alignment.center, child: Text(widget.note ?? "")))
                ])))
      ],
    );
  }
}

==> 11.3.0.tar.gz: lib/XfXWidgets/XfxItemForList.dart <==
part of xwidgetbase;

class XfxItemForList extends StatefulWidget {
  XfxItemForList({Key? key, this.title = "", this.descr, this.note, this.editable, this.colorBorderReadOnly}) : super(key: key);
  final String title;
  final String? descr;
  final String? note;
  final bool? editable;
  final Color? colorBorderReadOnly;
  @override
  _XfxItemForListState createState() => _XfxItemForListState();
}

class _XfxItemForListState extends State<XfxItemForList> {
  InputBorder? borderStyle() {
    return UnderlineInputBorder(borderRadius: BorderRadius.all(Radius.circular(4.0)), borderSide: BorderSide(width: 1, color: Colors.white));
  }

  @override
  Widget build(BuildContext context) {
    return Row(
      children: [
        Expanded(
            child: Container(
                decoration: BoxDecoration(
                  borderRadius: BorderRadius.all(Radius.circular(10)),
                  color: Colors.grey[850],
                ),
                margin: EdgeInsets.only(
                  bottom: 5,
                ),
                padding: EdgeInsets.only(bottom: 5),
                alignment: Alignment.centerLeft,
                child: Row(children: [
                  Expanded(
                      child: widget.editable == true
                          ? XTextFormField(
                              height: 40,
                              textColor: XColors.foregroundLight,
                              initialValue: widget.title,
                              border: borderStyle(),
                              disabledBorder: borderStyle(),
                              enabledBorder: borderStyle(),
                            )
                          : Container(height: 40, decoration: BoxDecoration(), alignment: Alignment.center, child: Text(widget.title))),
                  Expanded(child: widget.editable == true ? XTextFormField(height: 40, initialValue: widget.descr, border: borderStyle(), disabledBorder: borderStyle(), enabledBorder: borderStyle(), hintStyle: TextStyle(color: XColors.foregroundLight)) : Container(height: 40, decoration: BoxDecoration(), alignment: Alignment.center, child: Text(widget.descr ?? ""))),
                  Expanded(child: widget.editable == true ? XTextFormField(height: 40, initialValue: widget.note, border: borderStyle(), disabledBorder: borderStyle(), enabledBorder: borderStyle()) : Container(height: 40, decoration: BoxDecoration(), alignment: Alignment.center, child: Text(widget.note ?? "")))
                ])))
      ],
    );
  }
}
